.TH PARIS 1
.SH NAME
paris \- genome rearrangement program
.SH SYNOPSIS
.B paris processname inputfile1 inputfile2 [-s] [-o] [-p] [-l] [-b] [-t] [-c] [-B burn-in_number] [-T number_of_total_samples] [-I iterations_between_two_samples] [-S random_seed]

.BR

processname: All the output files' name will start with this.
.BR

inputfile1, inputfile2: See ParIS/help.html for a description on input format.
.BR


.SH  DESCRIPTION
This is a genome rearrangement program. It takes the gene orders and reading directions of two genomes and samples from the posterior probabilities of trajectories transforming the first genome into the second one using a Par tial I mportance S ampler technique, which is a version of the large class of Markov chain Monte Carlo methods. The algorithm is described in references below. 

Trajectory: In this file, each line describes a trajectory sampled. Mutations are separated by'|'. The first number shows the type of the mutation:

• 0: transposition

• 1: inverted transposition, where the right block is inverted

• 2: inverted transposition, where the left block is inverted

• 3: inversion


Following numbers are the positions where the mutation acts (breakpoints). The positions are given for the actual gene order. Transpositions and inverted transpositions have three breakpoints, inversions have only two. This is an example trajectory: 

2 2 4 33|0 11 13 21|3 3 34 |0 16 17 27|2 4 7 35|2 0 2 34|

Genomes can be submitted in files. The format is the following:

• The first line can be arbitrary long.

• Genes are listed from the second line. First the reading direction of the gene should be given followed by the name or abreviation of the gene. Corresponding genes in the two genomes must have the same name or abbreviation in both files!

• The last row of the file should be //


You can download Metazoa mitochondrial genomes in the above format from here:
http://www.stats.ox.ac.uk/~miklos/metazoa.zip
First lines of the files contain the NCBI access number, common name and scientific name.

The user can specify several marginalizations to the posterior:

• Posterior joint distribution of number of inversions and transpositions needed to transform one genome to another. The user also can specify angles with which the 3D graphics will be rotated Below is an example output: 

• Posterior distribution of length of the mutations. Be aware that we cannot distinguish a k long and an n-k long inversion for circular genomes, where n is the number of genes in that genome! Similarly, a transpositions and inverted transpositions cut a genome into three parts, and we cannot see which part was moved. Therefore for circular genomes, always the shorter intervals are reported in the posterior distribution of mutation lengths. See below an example output: 

• The expected number of mutations acting before or after a particular gene. ( Breakpoint distribution) This distribution tells the posterior probability that a mutation acts at a given site multiplied by the expected number of mutations happened. See below an example output: 

The user can also specify if s/he wants to get plain text file of the output and/or.ps or.pdf visualisations of the desired distribution(s). Optional parameters are the number of steps in the Markov chain for burn-in, the nuber of samples from the Markov chain, the nuber of steps between two samples and the random seed of the process.

Burnin: Although we found the Markov chain converging to the posterior distribution quite quick, we encourige users to set the burnin at least 10000 iterations. 

Samples: This parameter defines the total samples from the Markov chain. Greater values give better estimations, however, the analysis will be slower. 

Iterations: This parameter defines the number of steps in the Markov chain between two samples. Greater values yield less correlated samples, however, they also slow down the analysis Random seed: The program uses pseudorandom numbers, therefore if you want two independent runs, you must give two different random seeds! 

The log file gives a qualitative picture about the goodness of the chain. The text file contains the number of mutations, evolutionary probabilities, acceptance ratios and log likelihoods, the graphical output gives the log likelihood trace.  
.SH  OPTIONS

.TP
.B -s
Silent mode.
.TP
.B -o
Generates a processname.log file containing the signed permutation calculated from the input files, followed by information on samples. These later are: rates of inversion,  transposition,  number  of  inversions, transpositions in the sample, likelihood, number  of  acceptance,  real acceptance. The later two tell how many times the proposals were accepted, and how many times accepted proposals  differed  from  the  actualstate the Markov chain was.
.TP
.B -p
Generates the posterior distribution of number of inversions and transpositions needed. File name is processname.posterior
.TP
.B -l
Generates processname.length file containing the length distribution of mutations.
.TP
.B -b
Generates processname.breakpoint file containing the expected number of mutations happened before and after a gene.
.TP
.B -t
Generates processname.trajectory file containing the trajectories  sampled. See ParIS/help.html for more details on the trajectory files.
.TP
.B -c
Treats the genomes as circular genomes.
.TP
.B -B number
Gives the number of burn-in steps. Default value is 10000.
.TP
.B -T number
Gives the number of samples. Default value is 1000.
.TP
.B -I number
Gives the number of iterations between two samples.  Default  value  is
1000.
.TP
.B -S number
Gives the seed for random number generator. Default value is 0.

.SH EXAMPLES
Let's say the two genomes we want  to  analyse  are  in  files  
.I 
infile1
  and
.I 
infile2
Then the command:
.B paris myfirstrun infile1 infile2 -o -p -l -b -t -B 30000 -I 1000 -T 1000 > log

generates the following files:
 
.I myfirstrun.log

.I myfirstrun.posterior

.I myfirstrun.length

.I myfirstrun.breakpoint

.I myfirstrun.trajectory


treating the genomes as linear ones. The  Markov  chain  has  30000  steps  for burn-in, it samples after each 1000 steps, getting 1000 samples. If you want to get graphical outputs then give the following commands:

.TP
.B posteriori3D myfirstrun.posterior myfirstrun_posterior.ps

.TP
.B breakpoint myfirstrun.breakpoint myfirstrun_breakpoint.ps

.TP
.B length myfirstrun.length myfirstrun_length.ps

.TP
.B tail -n 1001 myfirstrun.log|cut -d " " -f 17 >temp.txt

.TP
.B trace temp.txt myfirstrun_loglikelihoodtrace.ps

.SH  REFERENCES

• Miklós, I. (2003) MCMC Genome Rearrangement Bioinformatics, special
issue for ECCB2003 19(Suppl.2):ii130-ii137. *

• Miklós, I., Ittzés, P. & Hein, J. (2004) ParIS Genome Rearrangement
server Submitted to Bioinformatics

.SH  ERRATUM!
In * this paper, equation (18) ougth to be

sum_i ( l(c_i) - p(c_i) choose 2) + ( p(c_i) choose 2)

instead of

sum_i ( l(c_i) - p(c_i))^2 + p(c_i)^2

Many thanks for the anonymous referee catching this error!


.SH FEEDBACK
 Please, send any comments to miklosi@ramet.elte.hu.
 Please, send any comments/bugs/solutions regarding the Plan 9 port to cej@gli.cas.cz.



.SH "SEE ALSO"
.IR aposteriori3D (1),
.IR breakpoint (1),
.IR length (1),
.IR trace (1)
